use axum::{extract::Request, middleware::Next, response::{IntoResponse, Response}};
use http::{header, StatusCode};
use jsonwebtoken::{decode, DecodingKey, Validation};

use crate::{config, token::Claims};


pub async fn authenticate_access_token(mut req: Request, next: Next) -> Response {
    let auth_header = req.headers().get(header::AUTHORIZATION);
    let token = match auth_header {
        Some(header_value) => {
            let parts: Vec<&str> = header_value.to_str().unwrap_or("").split_whitespace().collect();
            if parts.len() != 2 || parts[0] != "Bearer" {
                return (StatusCode::BAD_REQUEST, "Invalid authorization header format".to_string()).into_response();
            }
            parts[1]
        },
        None => return (StatusCode::UNAUTHORIZED, "Missing authorization header".to_string()).into_response(),
    };

    let validation = Validation::default();
    match decode::<Claims>(token, &DecodingKey::from_secret(config!().jwt.secret.as_bytes()), &validation) {
        Ok(decoded) => {
            // 将Claims附加到请求扩展中，以便后续处理使用
            req.extensions_mut().insert(decoded.claims);
            next.run(req).await
        },
        Err(_) => (StatusCode::UNAUTHORIZED, "Invalid token".to_string()).into_response(),
    }
}