use domain::dto::player_info::PlayerInfoRegister;
use domain::entities::player_info::PlayerInfo;
use library::db;
use library::resp::response::ResErr::{ErrPerm, ErrSystem};
use library::resp::response::{ResOK, ResResult};

pub async fn register(req: PlayerInfoRegister) -> ResResult<ResOK<()>> {
    match PlayerInfo::find_by_platform_id(req.platform_id.clone().unwrap().as_mut_str(), db!())
        .await
    {
        Err(err) => {
            tracing::error!(error = ?err, "查询账号失败");
            return Err(ErrSystem(None));
        }
        Ok(v) => {
            if v.id > 0 {
                return Err(ErrPerm(Some("用户已存在".to_string())));
            }
        }
    }

    match PlayerInfo::add_player_info(
        &mut PlayerInfo{
            username: req.username.unwrap(),
            email: req.email.unwrap(),
            platform_id: req.platform_id.unwrap(),
            user_type: req.user_type.unwrap(),
            country_code: req.country_code.unwrap(),
            ..Default::default()
        }, db!()
    ).await {
        Ok(player_info) => {
            tracing::info!("添加账户成功: {:?}", player_info)
        }
        Err(err) => {
            tracing::error!(error = ?err, "添加账号失败");
            return Err(ErrSystem(None));
        }
    }

    Ok(ResOK(None))
}
